@@ -1,70 +1,84 @@
+// SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+// SPDX-License-Identifier: GPL-2.0-or-later
 //! Common definitions for the IP range output tool.
-/*
- * Copyright (c) 2021  Peter Pentchev <roam@ringlet.net>
- * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- */
 
+use std::error::Error as StdError;
+use std::fmt::{Display, Error as FmtError, Formatter};
 use std::str::FromStr;
 
-use anyhow::{anyhow, Error as AnyError};
-use thiserror::Error;
+use eyre::{Error as AnyError, bail};
 
 /// An error that most likely occurred while parsing the IP address specifications.
-#[allow(clippy::error_impl_error)]
-#[derive(Debug, Error)]
+#[expect(clippy::error_impl_error, reason = "common enough convention")]
+#[derive(Debug)]
 pub enum Error {
     /// Invalid start address for a CIDR range.
-    #[error("CIDR base address didn't start at subnet boundary")]
     CidrBadStart,
 
     /// Invalid offset for a CIDR range.
-    #[error("CIDR offsets are between 0 and 32")]
     CidrPrefixTooLarge,
 
     /// Something went really, really wrong.
-    #[error("prips internal error")]
-    Internal(#[source] AnyError),
+    Internal(AnyError),
 
     /// Could not parse an IP address.
-    #[error("Could not parse '{0}' as a valid IP address")]
-    ParseAddress(String, #[source] AnyError),
+    ParseAddress(String, AnyError),
 
     /// Could not parse an IP address / prefix length CIDR spec.
-    #[error("Could not parse '{0}' as a valid CIDR specification")]
-    ParseCidr(String, #[source] AnyError),
+    ParseCidr(String, AnyError),
 
     /// Could not parse an exclusion mask.
-    #[error("Could not parse '{0}' as a 0-255 integer value")]
-    ParseExclude(String, #[source] AnyError),
+    ParseExclude(String, AnyError),
 
     /// Invalid IP range specified.
-    #[error("The start address must be smaller than the end address")]
     StartBeforeEnd,
 }
 
+impl Display for Error {
+    /// Describe the error that occurred.
+    #[inline]
+    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), FmtError> {
+        match *self {
+            Self::CidrBadStart => write!(f, "CIDR base address didn't start at subnet boundary"),
+
+            Self::CidrPrefixTooLarge => write!(f, "CIDR offsets are between 0 and 32"),
+
+            Self::Internal(_) => write!(f, "prips internal error"),
+
+            Self::ParseAddress(ref value, _) => {
+                write!(f, "Could not parse '{value}' as a valid IP address")
+            }
+
+            Self::ParseCidr(ref value, _) => {
+                write!(f, "Could not parse '{value}' as a valid CIDR specification")
+            }
+
+            Self::ParseExclude(ref value, _) => {
+                write!(f, "Could not parse '{value}' as a 0-255 integer value")
+            }
+
+            Self::StartBeforeEnd => {
+                write!(f, "The start address must be smaller than the end address")
+            }
+        }
+    }
+}
+
+impl StdError for Error {
+    #[inline]
+    fn source(&self) -> Option<&(dyn StdError + 'static)> {
+        match *self {
+            Self::CidrBadStart | Self::CidrPrefixTooLarge | Self::StartBeforeEnd => None,
+            Self::Internal(ref err)
+            | Self::ParseAddress(_, ref err)
+            | Self::ParseCidr(_, ref err)
+            | Self::ParseExclude(_, ref err) => Some(err.as_ref()),
+        }
+    }
+}
+
 /// An inclusive IPv4 address range.
-#[derive(Debug)]
+#[derive(Debug, Eq, PartialEq)]
 pub struct AddrRange {
     /// The first address in the range.
     pub start: u32,
@@ -90,7 +104,7 @@ impl FromStr for AddrFormat {
             "dot" => Ok(Self::Dot),
             "dec" => Ok(Self::Dec),
             "hex" => Ok(Self::Hex),
-            _ => Err(anyhow!("Unrecognized address format specified")),
+            _ => bail!("Unrecognized address format specified"),
         }
     }
 }
