@@ -1,36 +1,13 @@
+// SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+// SPDX-License-Identifier: GPL-2.0-or-later
 //! Output a range of IP addresses.
-/*
- * Copyright (c) 2021  Peter Pentchev <roam@ringlet.net>
- * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- */
 
 use std::iter::{FusedIterator, StepBy};
 use std::ops::RangeInclusive;
 
 use crate::defs::{AddrExclude, AddrFormat, Config, Error};
 
-use anyhow::anyhow;
+use eyre::eyre;
 
 fn format_dot(addr: u32) -> String {
     format!(
@@ -152,9 +129,9 @@ pub fn cidrize(cfg: &Config) -> Result<String, Error> {
         } else {
             let mask = u32::MAX
                 .checked_shl(offset)
-                .ok_or_else(|| Error::Internal(anyhow!("Could not compute a mask for {offset}")))?;
+                .ok_or_else(|| Error::Internal(eyre!("Could not compute a mask for {offset}")))?;
             let prefixlen = 31_u32.checked_sub(offset).ok_or_else(|| {
-                Error::Internal(anyhow!(
+                Error::Internal(eyre!(
                     "Got an offset larger than 31 for {start}..{end}",
                     start = cfg.range.start,
                     end = cfg.range.end,
@@ -167,9 +144,9 @@ pub fn cidrize(cfg: &Config) -> Result<String, Error> {
 }
 
 #[cfg(test)]
-#[allow(clippy::panic_in_result_fn)]
+#[expect(clippy::panic_in_result_fn, reason = "unit tests")]
 mod tests {
-    use anyhow::{Context as _, Result};
+    use eyre::{Result, WrapErr as _};
     use itertools::Itertools as _;
     use rstest::rstest;
 
